from __future__ import print_function
import gzip
import re
import lsst.daf.base as dafBase


class CsvFileWriter(object):

    def __init__(self, path, overwrite=True, compress=True):
        if compress:
            self.f = gzip.open(path + ".gz", "w" if overwrite else "a")
        else:
            self.f = open(path, "w" if overwrite else "a")

    def __del__(self):
        self.f.close()

    def flush(self):
        self.f.flush()

    def quote(self, value):
        if value is None:
            return '\N'
        if isinstance(value, float):
            return "%.17g" % (value,)
        if isinstance(value, str):
            value = re.sub(r'"', r'\"', value)
            return '"' + value.strip() + '"'
        if isinstance(value, dafBase.DateTime):
            value = value.toString(dafBase.DateTime.UTC)
            return '"' + value[0:10] + ' ' + value[11:19] + '"'
        return str(value)

    def write(self, *fields):
        print(",".join([self.quote(field) for field in fields]), file=self.f)
